@@ -1,7 +1,7 @@
-# SpectroscPy 0.1.0
+# SpectroscPy 0.2.0
 # SpectroscPy is a script package developed by and containing contributions from
 
-    # Karen Oda Hjorth Dundas
+    # Karen Oda Hjorth Minde Dundas
     # Magnus Ringholm
     # Yann Cornation
     # Benedicte Ofstad
@@ -23,6 +23,7 @@ avogadros_constant     = 6.02214075862e23
 plancs_constant        = 6.62607015e-34
 speed_of_light         = 299792458
 boltzmann_constant_SI  = 1.38064852e-23
+sqrt2                  = sqrt(2)
 
 # mass of one electron in kg, or in other words conversion factor from au to kg
 electron_mass = 9.1093829140e-31
@@ -33,11 +34,23 @@ one_twelfth_carbon = 1.66053904020e-27
 debye_to_coulomb_meter = 10**(-21)/speed_of_light
 angstrom_to_meter      = 1.0e-10
 
-fermi_threshold  = 200.0
-martin_threshold = 1.0
+# Here converted from 1/cm to J since that is what is needed in the routine.
+fermi_threshold  = 200.0*100*plancs_constant*speed_of_light
+martin_threshold = 1.0*100*plancs_constant*speed_of_light
 
 hess_operator = ['GEO', 'GEO']
+cubic_operator = ['GEO', 'GEO', 'GEO']
+quartic_operator = ['GEO', 'GEO', 'GEO', 'GEO']
+
 dip_grad_operator = ['GEO', 'EL']
+dip_hess_operator = ['GEO', 'GEO', 'EL']
+dip_cubic_operator = ['GEO', 'GEO', 'GEO', 'EL']
+
 polariz_grad_operator = ['GEO', 'EL', 'EL']
+polariz_hess_operator = ['GEO', 'GEO', 'EL', 'EL']
+polariz_cubic_operator = ['GEO', 'GEO', 'GEO', 'EL', 'EL']
+
 hyper_polariz_grad_operator = ['GEO', 'EL', 'EL', 'EL']
+hyper_polariz_hess_operator = ['GEO', 'GEO', 'EL', 'EL', 'EL']
+hyper_polariz_cubic_operator = ['GEO', 'GEO', 'GEO', 'EL', 'EL', 'EL']
 
