@@ -1,7 +1,7 @@
-# SpectroscPy 0.1.0
+# SpectroscPy 0.2.0
 # SpectroscPy is a script package developed by and containing contributions from
 
-    # Karen Oda Hjorth Dundas
+    # Karen Oda Hjorth Minde Dundas
     # Magnus Ringholm
     # Yann Cornation
     # Benedicte Ofstad
@@ -16,7 +16,6 @@
 
 from spectroscpy import get_vib_harm_freqs_and_eigvecs, project_out_transl_and_rot, read_mol, \
                         mol_is_linear, get_vibrational_w
-import pytest
 import os
 import numpy as np
 
@@ -93,6 +92,7 @@ def test_read_mol():
 
 def test_project_out_transl_and_rot():
 
+    # Non-linear case
     coordinates = [[1.69509813, -0.01831334, 1.84778681], [-0.83741626, -1.47927283, -1.84733382], \
                    [0.12223015, 0.06073168, -1.31223], [-0.11825048, -0.07620551, 1.31178901]]
 
@@ -135,7 +135,73 @@ def test_project_out_transl_and_rot():
                       9.96461236e-03, -3.47559190e-02,  6.03663475e-02,  2.45565362e-03, \
                      -6.34802352e-01,  8.50812867e-02, -1.56513812e-03,  7.65914732e-01]]
 
-    vib_hess = project_out_transl_and_rot(num_vib_modes, hess, coordinates)
+    vib_hess = project_out_transl_and_rot(num_vib_modes, hess, coordinates, False)
+
+    assert np.allclose(ref_vib_hess, vib_hess)
+
+    # Linear case (CO2)
+    coordinates = [[-5.73169685, -0.11606755, -0.0], [-3.58625798, -0.03208891, -0.0], \
+                   [-7.87713569, -0.20006337, -0.0]]
+
+    num_vib_modes = 4
+
+    CO2_hess = [[ 2.16864638e+00,  7.71736983e-02,  7.42177568e-16, -1.08432757e+00,
+             -3.85785562e-02, -6.51798770e-15, -1.08432403e+00, -3.85862989e-02,
+              1.53250016e-14],
+            [ 7.71736983e-02,  2.00332269e-01,  3.80178334e-16, -3.85820493e-02,
+             -1.00166430e-01, -5.35393596e-16, -3.85891281e-02, -1.00167310e-01,
+              5.29471622e-16],
+            [ 7.42177568e-16,  3.80178334e-16,  1.97311311e-01,  7.28179980e-16,
+             -1.35525820e-16, -9.86568443e-02,  2.97019598e-15, -6.20345805e-17,
+             -9.86571386e-02],
+            [-1.08432757e+00, -3.85820493e-02,  7.28179980e-16,  1.23232064e+00,
+              4.63064775e-02,  3.26460221e-15, -1.47993064e-01, -7.72758921e-03,
+             -6.64828911e-15],
+            [-3.85785562e-02, -1.00166430e-01, -1.35525820e-16,  4.63064775e-02,
+              5.11386697e-02,  2.62922778e-16, -7.72466151e-03,  4.90277601e-02,
+             -1.90631061e-16],
+            [-6.51798770e-15, -5.35393596e-16, -9.86568443e-02,  3.26460221e-15,
+              2.62922778e-16,  4.93260892e-02, -3.17178737e-16,  1.13019220e-16,
+              4.93307552e-02],
+            [-1.08432403e+00, -3.85891281e-02,  2.97019598e-15, -1.47993064e-01,
+             -7.72466151e-03, -3.17178737e-16,  1.23231709e+00,  4.63138881e-02,
+             -8.67671247e-15],
+            [-3.85862989e-02, -1.00167310e-01, -6.20345805e-17, -7.72758921e-03,
+              4.90277601e-02,  1.13019220e-16,  4.63138881e-02,  5.11395501e-02,
+             -3.38840561e-16],
+            [ 1.53250016e-14,  5.29471622e-16, -9.86571386e-02, -6.64828911e-15,
+             -1.90631061e-16,  4.93307552e-02, -8.67671247e-15, -3.38840561e-16,
+              4.93263834e-02]]
+
+    ref_vib_hess = [[ 2.16864928e+00,  7.71705526e-02, -3.82370119e-15, -1.08432645e+00,
+                     -3.85810053e-02,  1.91204613e-15, -1.08432283e+00, -3.85895472e-02,
+                      1.91165505e-15],
+                    [ 7.71705526e-02,  2.00333086e-01,  1.97162098e-16, -3.85811887e-02,
+                     -1.00166228e-01, -9.85911316e-17, -3.85893638e-02, -1.00166858e-01,
+                     -9.85709663e-17],
+                    [-3.82370119e-15,  1.97162098e-16,  1.97312794e-01,  2.29126422e-16,
+                     -1.64462098e-16, -9.86664873e-02,  3.59457477e-15, -3.26999995e-17,
+                     -9.86463067e-02],
+                    [-1.08432645e+00, -3.85811887e-02,  2.29126422e-16,  1.23232015e+00,
+                      4.63059113e-02, -1.14574928e-16, -1.47993696e-01, -7.72472253e-03,
+                     -1.14551494e-16],
+                    [-3.85810053e-02, -1.00166228e-01, -1.64462098e-16,  4.63059113e-02,
+                      5.11406052e-02,  8.22394596e-17, -7.72490593e-03,  4.90256227e-02,
+                      8.22226388e-17],
+                    [ 1.91204613e-15, -9.85911316e-17, -9.86664873e-02, -1.14574928e-16,
+                      8.22394596e-17,  4.93382893e-02, -1.79747120e-15,  1.63516720e-17,
+                      4.93281980e-02],
+                    [-1.08432283e+00, -3.85893638e-02,  3.59457477e-15, -1.47993696e-01,
+                     -7.72490593e-03, -1.79747120e-15,  1.23231653e+00,  4.63142697e-02,
+                     -1.79710356e-15],
+                    [-3.85895472e-02, -1.00166858e-01, -3.26999995e-17, -7.72472253e-03,
+                      4.90256227e-02,  1.63516720e-17,  4.63142697e-02,  5.11412356e-02,
+                      1.63483275e-17],
+                    [ 1.91165505e-15, -9.85709663e-17, -9.86463067e-02, -1.14551494e-16,
+                      8.22226388e-17,  4.93281980e-02, -1.79710356e-15,  1.63483275e-17,
+                      4.93181087e-02]]
+
+    vib_hess = project_out_transl_and_rot(num_vib_modes, CO2_hess, coordinates, True)
 
     assert np.allclose(ref_vib_hess, vib_hess)
 
@@ -251,6 +317,79 @@ def test_get_vib_harm_freqs_and_eigvecs():
     assert np.allclose(ref_T, transformation_matrix)
     assert ref_num_coordinates == num_coordinates
 
+    # Linear molecule (CO2)
+    coordinates = [[-5.73169685, -0.11606755, -0.0], [-3.58625798, -0.03208891, -0.0], \
+                   [-7.87713569, -0.20006337, -0.0]]
+    charges = [6, 8, 8]
+    masses = [12.0, 15.994915, 15.994915]
+
+    CO2_hess = [[ 2.16864638e+00,  7.71736983e-02,  7.42177568e-16, -1.08432757e+00,
+             -3.85785562e-02, -6.51798770e-15, -1.08432403e+00, -3.85862989e-02,
+              1.53250016e-14],
+            [ 7.71736983e-02,  2.00332269e-01,  3.80178334e-16, -3.85820493e-02,
+             -1.00166430e-01, -5.35393596e-16, -3.85891281e-02, -1.00167310e-01,
+              5.29471622e-16],
+            [ 7.42177568e-16,  3.80178334e-16,  1.97311311e-01,  7.28179980e-16,
+             -1.35525820e-16, -9.86568443e-02,  2.97019598e-15, -6.20345805e-17,
+             -9.86571386e-02],
+            [-1.08432757e+00, -3.85820493e-02,  7.28179980e-16,  1.23232064e+00,
+              4.63064775e-02,  3.26460221e-15, -1.47993064e-01, -7.72758921e-03,
+             -6.64828911e-15],
+            [-3.85785562e-02, -1.00166430e-01, -1.35525820e-16,  4.63064775e-02,
+              5.11386697e-02,  2.62922778e-16, -7.72466151e-03,  4.90277601e-02,
+             -1.90631061e-16],
+            [-6.51798770e-15, -5.35393596e-16, -9.86568443e-02,  3.26460221e-15,
+              2.62922778e-16,  4.93260892e-02, -3.17178737e-16,  1.13019220e-16,
+              4.93307552e-02],
+            [-1.08432403e+00, -3.85891281e-02,  2.97019598e-15, -1.47993064e-01,
+             -7.72466151e-03, -3.17178737e-16,  1.23231709e+00,  4.63138881e-02,
+             -8.67671247e-15],
+            [-3.85862989e-02, -1.00167310e-01, -6.20345805e-17, -7.72758921e-03,
+              4.90277601e-02,  1.13019220e-16,  4.63138881e-02,  5.11395501e-02,
+             -3.38840561e-16],
+            [ 1.53250016e-14,  5.29471622e-16, -9.86571386e-02, -6.64828911e-15,
+             -1.90631061e-16,  4.93307552e-02, -8.67671247e-15, -3.38840561e-16,
+              4.93263834e-02]]
+
+    ref_vib_energies = [0.01168413, 0.00688573, 0.0035219,  0.00352189]
+
+    ref_T = [[-5.76138140e-03,  4.51914042e-09,  9.89553346e-14, -2.25536758e-04,
+               2.44638062e-03,  2.97137698e-03,  2.97137698e-03,  3.23829033e-03,
+               3.23829033e-03],
+             [-2.25536758e-04,  4.51764187e-08, -2.52811545e-12,  5.76138140e-03,
+               4.39406391e-04,  6.42672128e-04,  6.42672128e-04, -3.07561126e-04,
+              -3.07561126e-04],
+             [ 1.11370401e-17, -1.96228205e-17, -5.76579417e-03, -3.16526184e-12,
+              -1.05461341e-03, -1.29138409e-03, -1.29138409e-03, -3.25963710e-06,
+              -3.25963710e-06],
+             [ 2.16120973e-03,  4.13791220e-03, -3.71180195e-14,  8.45709149e-05,
+               2.53984913e-03,  2.98952229e-03,  2.98952229e-03,  3.23532865e-03,
+               3.23532865e-03],
+             [ 8.45947082e-05,  1.61969458e-04,  9.48345710e-13, -2.16120647e-03,
+              -1.94847447e-03,  1.79105965e-04,  1.79105965e-04, -2.31897781e-04,
+              -2.31897781e-04],
+             [-4.17742129e-18,  6.88938217e-18,  2.16308141e-03,  1.18747146e-12,
+              -2.24337865e-03, -2.31143387e-03, -2.31143387e-03, -3.38842799e-06,
+              -3.38842799e-06],
+             [ 2.16120004e-03, -4.13791559e-03, -3.71218328e-14,  8.46354294e-05,
+               2.35289298e-03,  2.95322795e-03,  2.95322795e-03,  3.24125261e-03,
+               3.24125261e-03],
+             [ 8.46116361e-05, -1.62003351e-04,  9.48345007e-13, -2.16120330e-03,
+               2.82728722e-03,  1.10623828e-03,  1.10623828e-03, -3.83224469e-04,
+              -3.83224469e-04],
+             [-4.17657299e-18,  6.87753819e-18,  2.16263898e-03,  1.18722860e-12,
+               1.34395024e-04, -2.71125631e-04, -2.71125631e-04, -3.13081986e-06,
+              -3.13081986e-06]]
+
+    ref_num_coordinates = 9
+
+    vib_energies, transformation_matrix, num_coordinates = \
+        get_vib_harm_freqs_and_eigvecs(coordinates, charges, masses, CO2_hess, True, 0)
+
+    assert np.allclose(ref_vib_energies, vib_energies)
+    assert np.allclose(ref_T, transformation_matrix)
+    assert ref_num_coordinates == num_coordinates
+
 
 def test_get_vibrational_w():
 
